@@ -733,6 +733,8 @@ namespace ModelInstance
           mFinal = true;
         } else if (modifierKey.compare(QStringLiteral("each")) == 0) {
           mEach = true;
+        } else if (modifierKey.compare(QStringLiteral("comment")) == 0) {
+          mComment = modifierValue.toString();
         } else if (modifierKey.compare(QStringLiteral("$value")) == 0) {
           if (modifierValue.isObject()) {
             QJsonObject valueObject = modifierValue.toObject();
@@ -759,7 +761,7 @@ namespace ModelInstance
     }
   }
 
-  QString Modifier::toString(bool skipTopLevel) const
+  QString Modifier::toString(bool skipTopLevel, bool includeComment) const
   {
     if (mpElement) {
       return mpElement->toString(skipTopLevel);
@@ -777,15 +779,14 @@ namespace ModelInstance
       if (!subModifiers.isEmpty()) {
         value.append("(" % subModifiers.join(", ") % ")");
       }
-      if (mValue.isEmpty()) {
-        if (value.compare(mName) != 0) {
-          return value;
-        } else {
-          return "";
-        }
-      } else {
-        return value.append(mName.isEmpty() ? mValue : " = " % mValue);
+      if (!mValue.isEmpty()) {
+        value.append(mName.isEmpty() ? mValue : " = " % mValue);
       }
+      if (includeComment && !mComment.isEmpty()) {
+        value.append(" \"" % mComment % "\"");
+      }
+
+      return value.compare(mName) == 0 ? "" : value;
     }
   }
 
@@ -1074,22 +1075,7 @@ namespace ModelInstance
       mpPrefixes->deserialize(mModelJson.value("prefixes").toObject());
     }
 
-    QJsonArray elements = mModelJson.value("elements").toArray();
-
-    foreach (const QJsonValue &element, elements) {
-      QJsonObject elementObject = element.toObject();
-      QString kind = elementObject.value("$kind").toString();
-
-      if (kind.compare(QStringLiteral("extends")) == 0) {
-        mElements.append(new Extend(this, elementObject));
-      } else if (kind.compare(QStringLiteral("component")) == 0) {
-        mElements.append(new Component(this, elementObject));
-      } else if (kind.compare(QStringLiteral("class")) == 0) {
-        mElements.append(new ReplaceableClass(this, elementObject));
-      } else {
-        qDebug() << "Model::deserialize() unhandled kind of element" << kind;
-      }
-    }
+    deserializeElements(mModelJson.value("elements").toArray());
 
     if (mModelJson.contains("comment")) {
       mComment = mModelJson.value("comment").toString();
@@ -1157,6 +1143,29 @@ namespace ModelInstance
     }
   }
 
+  /*!
+   * \brief Model::deserializeElements
+   * Deserializes the elements JSON and adds the elements to the model.
+   * \param elements
+   */
+  void Model::deserializeElements(const QJsonArray elements)
+  {
+    foreach (const QJsonValue &element, elements) {
+      QJsonObject elementObject = element.toObject();
+      QString kind = elementObject.value("$kind").toString();
+
+      if (kind.compare(QStringLiteral("extends")) == 0) {
+        mElements.append(new Extend(this, elementObject));
+      } else if (kind.compare(QStringLiteral("component")) == 0) {
+        mElements.append(new Component(this, elementObject));
+      } else if (kind.compare(QStringLiteral("class")) == 0) {
+        mElements.append(new ReplaceableClass(this, elementObject));
+      } else {
+        qDebug() << "Model::deserialize() unhandled kind of element" << kind;
+      }
+    }
+  }
+
   Extend *Model::getParentExtend() const
   {
     if (mpParentElement && mpParentElement->isExtend()) {
@@ -1369,6 +1378,11 @@ namespace ModelInstance
       return true;
     }
 
+    Model *lhs_model = lhs->getModel();
+    Model *rhs_model = rhs->getModel();
+
+    if (!lhs_model || !rhs_model) return true;
+
     auto lhs_outside = isOutsideConnector(lhsConnector, *this);
     auto rhs_outside = isOutsideConnector(rhsConnector, *this);
 
@@ -1377,11 +1391,6 @@ namespace ModelInstance
     }
 
     // Check that the connectors are type compatible.
-    Model *lhs_model = lhs->getModel();
-    Model *rhs_model = rhs->getModel();
-
-    if (!lhs_model || !rhs_model) return false;
-
     return lhs_model->isTypeCompatibleWith(*rhs_model, lhs_outside, rhs_outside);
   }
 
@@ -1754,7 +1763,7 @@ namespace ModelInstance
     }
   }
 
-  QStringList Choices::getChoicesStringList() const
+  QStringList Choices::getChoicesValueStringList() const
   {
     QStringList choices;
     foreach (auto *pChoice, mChoices) {
@@ -1763,6 +1772,15 @@ namespace ModelInstance
     return choices;
   }
 
+  QStringList Choices::getChoicesCommentStringList() const
+  {
+    QStringList choices;
+    foreach (auto *pChoice, mChoices) {
+      choices.append(pChoice->toString(false, true));
+    }
+    return choices;
+  }
+
   Element::Element(Model *pParentModel)
   {
     mpParentModel = pParentModel;
@@ -2306,7 +2324,11 @@ namespace ModelInstance
     } else {
       mName = str.left(i);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+      for (const auto& sub: QStringView(str).mid(i + 1, str.size() - i - 2).split(',')) {
+#else
       for (const auto& sub: str.midRef(i + 1, str.size() - i - 2).split(',')) {
+#endif
         mSubScripts.append(sub.toString());
       }
     }
