@@ -303,7 +303,7 @@ QVariant ConnectorsModel::data(const QModelIndex &index, int role) const
 Qt::ItemFlags ConnectorsModel::flags(const QModelIndex &index) const
 {
   if (!index.isValid()) {
-    return 0;
+    return Qt::ItemFlags();
   } else {
     Qt::ItemFlags flags = Qt::ItemIsEnabled | Qt::ItemIsSelectable;
     ConnectorItem *pConnectorItem = static_cast<ConnectorItem*>(index.internalPointer());
@@ -515,7 +515,7 @@ void AddBusDialog::addBus()
 {
   if (mpNameTextBox->text().isEmpty()) {
     QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error),
-                          GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(tr("Bus")), Helper::ok);
+                          GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(tr("Bus")), QMessageBox::Ok);
     return;
   }
 
@@ -553,13 +553,21 @@ void AddBusDialog::addBus()
                                   .arg(QString(mpLibraryTreeItem->getOMSBusConnector()->connectors[i])));
       }
     }
-    // add connectors to the bus
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    QSet<QString> connectorsSet(connectors.begin(), connectors.end());
+    QSet<QString> existingConnectorsSet(existingConnectors.begin(), existingConnectors.end());
+    QSet<QString> addConnectors = connectorsSet.subtract(existingConnectorsSet);
+    QSet<QString> deleteConnectors = existingConnectorsSet.subtract(connectorsSet);
+#else // QT_VERSION_CHECK
     QSet<QString> addConnectors = connectors.toSet().subtract(existingConnectors.toSet());
+    QSet<QString> deleteConnectors = existingConnectors.toSet().subtract(connectors.toSet());
+#endif // QT_VERSION_CHECK
+    // add connectors to the bus
     foreach (QString connector, addConnectors) {
       OMSProxy::instance()->addConnectorToBus(bus, connector);
     }
     // delete connectors from the bus
-    QSet<QString> deleteConnectors = existingConnectors.toSet().subtract(connectors.toSet());
     foreach (QString connector, deleteConnectors) {
       OMSProxy::instance()->deleteConnectorFromBus(bus, connector);
     }
@@ -568,6 +576,12 @@ void AddBusDialog::addBus()
     accept();
   } else {  // add case
     if (OMSProxy::instance()->addBus(bus)) {
+      if (mpGraphicsView->mContextMenuStartPositionValid) {
+        ssd_connector_geometry_t connectorGeometry;
+        connectorGeometry.x = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
+        connectorGeometry.y = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
+        OMSProxy::instance()->setBusGeometry(bus, &connectorGeometry);
+      }
       foreach (QString connector, connectors) {
         OMSProxy::instance()->addConnectorToBus(bus, connector);
       }
@@ -803,7 +817,7 @@ void AddTLMBusDialog::addTLMBus()
 {
   if (mpNameTextBox->text().isEmpty()) {
     QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error),
-                          GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(tr("TLM Bus")), Helper::ok);
+                          GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(tr("TLM Bus")), QMessageBox::Ok);
     return;
   }
 
@@ -861,6 +875,12 @@ void AddTLMBusDialog::addTLMBus()
   } else {  // add case
     if (OMSProxy::instance()->addTLMBus(tlmBus, (oms_tlm_domain_t)mpDomainComboBox->itemData(mpDomainComboBox->currentIndex()).toInt(), mpDimensionSpinBox->value(),
                                         (oms_tlm_interpolation_t)mpInterpolationComboBox->itemData(mpInterpolationComboBox->currentIndex()).toInt())) {
+      if (mpGraphicsView->mContextMenuStartPositionValid) {
+        ssd_connector_geometry_t connectorGeometry;
+        connectorGeometry.x = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.x(), -100, 100, 0, 1);
+        connectorGeometry.y = Utilities::mapToCoOrdinateSystem(mpGraphicsView->mContextMenuStartPosition.y(), -100, 100, 0, 1);
+        OMSProxy::instance()->setTLMBusGeometry(tlmBus, &connectorGeometry);
+      }
       // add connectors to the bus
       QPair<QString, QString> connector;
       foreach (connector, connectors) {
@@ -1100,8 +1120,8 @@ QVariant ConnectionsModel::data(const QModelIndex &index, int role) const
         case Qt::DisplayRole:
         case Qt::ToolTipRole:
         {
-          LibraryTreeItem *pStartElement = mpConnectionLineAnnotation->getStartComponent()->getLibraryTreeItem()->parent();
-          LibraryTreeItem *pEndElement = mpConnectionLineAnnotation->getEndComponent()->getLibraryTreeItem()->parent();
+          LibraryTreeItem *pStartElement = mpConnectionLineAnnotation->getStartElement()->getLibraryTreeItem()->parent();
+          LibraryTreeItem *pEndElement = mpConnectionLineAnnotation->getEndElement()->getLibraryTreeItem()->parent();
           if (pStartElement && pEndElement && !pConnectionItem->getStart().isEmpty() && !pConnectionItem->getEnd().isEmpty()) {
             return QString("<ssd:Connection startElement=\"%1\" startConnector=\"%2\" endElement=\"%3\" endConnector=\"%4\" />")
                 .arg(pStartElement->getName(), pConnectionItem->getStart(), pEndElement->getName(), pConnectionItem->getEnd());
@@ -1330,8 +1350,8 @@ BusConnectionDialog::BusConnectionDialog(GraphicsView *pGraphicsView, LineAnnota
   // set separator line
   mpHorizontalLine = Utilities::getHeadingLine();
   // input output label
-  LibraryTreeItem *pStartLibraryTreeItem = mpConnectionLineAnnotation->getStartComponent()->getLibraryTreeItem();
-  LibraryTreeItem *pEndLibraryTreeItem = mpConnectionLineAnnotation->getEndComponent()->getLibraryTreeItem();
+  LibraryTreeItem *pStartLibraryTreeItem = mpConnectionLineAnnotation->getStartElement()->getLibraryTreeItem();
+  LibraryTreeItem *pEndLibraryTreeItem = mpConnectionLineAnnotation->getEndElement()->getLibraryTreeItem();
   Label *pInputOutputLabel = new Label(QString("Connect <b>%1</b> input connectors to <b>%2</b> output connectors")
                                        .arg(pStartLibraryTreeItem->getName())
                                        .arg(pEndLibraryTreeItem->getName()));
@@ -1424,8 +1444,8 @@ BusConnectionDialog::BusConnectionDialog(GraphicsView *pGraphicsView, LineAnnota
     for (int i = 0 ; i < mpGraphicsView->getConnectionsList().size() ; ++i) {
       LineAnnotation *pAtomicConnectionLineAnnotation = mpGraphicsView->getConnectionsList().at(i);
       if (pAtomicConnectionLineAnnotation && pAtomicConnectionLineAnnotation->getOMSConnectionType() == oms_connection_single) {
-        QString startConnectorName = StringHandler::getLastWordAfterDot(pAtomicConnectionLineAnnotation->getStartComponentName());
-        QString endConnectorName = StringHandler::getLastWordAfterDot(pAtomicConnectionLineAnnotation->getEndComponentName());
+        QString startConnectorName = StringHandler::getLastWordAfterDot(pAtomicConnectionLineAnnotation->getStartElementName());
+        QString endConnectorName = StringHandler::getLastWordAfterDot(pAtomicConnectionLineAnnotation->getEndElementName());
         if (startBusInputConnectors.contains(startConnectorName) && endBusOutputConnectors.contains(endConnectorName)) {
           ConnectionItem *pConnectionItem;
           pConnectionItem = mpInputOutputConnectionsModel->createConnectionItem(startConnectorName, endConnectorName, true,
@@ -1550,38 +1570,38 @@ void BusConnectionDialog::deleteAtomicConnection(QString startConnectorName, QSt
 {
   // get start connector
   Element *pStartComponent = 0;
-  Element *pBusStartComponent = mpConnectionLineAnnotation->getStartComponent();
-  if (pBusStartComponent && pBusStartComponent->getRootParentComponent()) {
-    pStartComponent = mpGraphicsView->getModelWidget()->getConnectorComponent(pBusStartComponent->getRootParentComponent(), startConnectorName);
+  Element *pBusStartComponent = mpConnectionLineAnnotation->getStartElement();
+  if (pBusStartComponent && pBusStartComponent->getRootParentElement()) {
+    pStartComponent = mpGraphicsView->getModelWidget()->getConnectorElement(pBusStartComponent->getRootParentElement(), startConnectorName);
   } else if (pBusStartComponent) {
     pStartComponent = mpGraphicsView->getElementObject(startConnectorName);
   }
   // get end connector
   Element *pEndComponent = 0;
-  Element *pBusEndComponent = mpConnectionLineAnnotation->getEndComponent();
-  if (pBusEndComponent && pBusEndComponent->getRootParentComponent()) {
-    pEndComponent = mpGraphicsView->getModelWidget()->getConnectorComponent(pBusEndComponent->getRootParentComponent(), endConnectorName);
+  Element *pBusEndComponent = mpConnectionLineAnnotation->getEndElement();
+  if (pBusEndComponent && pBusEndComponent->getRootParentElement()) {
+    pEndComponent = mpGraphicsView->getModelWidget()->getConnectorElement(pBusEndComponent->getRootParentElement(), endConnectorName);
   } else if (pBusEndComponent) {
     pEndComponent = mpGraphicsView->getElementObject(endConnectorName);
   }
   // delete connection once we have both start and end connectors
   if (pStartComponent && pEndComponent) {
     QString startComponentName = QStringLiteral("");
-    if (pStartComponent->getParentComponent()) {
-      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentComponent()->getName()).arg(pStartComponent->getName());
+    if (pStartComponent->getParentElement()) {
+      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentElement()->getName()).arg(pStartComponent->getName());
     } else {
       startComponentName = pStartComponent->getName();
     }
 
     QString endComponentName = QStringLiteral("");
-    if (pEndComponent->getParentComponent()) {
-      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentComponent()->getName()).arg(pEndComponent->getName());
+    if (pEndComponent->getParentElement()) {
+      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentElement()->getName()).arg(pEndComponent->getName());
     } else {
       endComponentName = pEndComponent->getName();
     }
 
     foreach (LineAnnotation *pConnectionLineAnnotation, mpGraphicsView->getConnectionsList()) {
-      if ((pConnectionLineAnnotation->getStartComponentName().compare(startComponentName) == 0) && (pConnectionLineAnnotation->getEndComponentName().compare(endComponentName) == 0)) {
+      if ((pConnectionLineAnnotation->getStartElementName().compare(startComponentName) == 0) && (pConnectionLineAnnotation->getEndElementName().compare(endComponentName) == 0)) {
         mpGraphicsView->removeConnectionFromView(pConnectionLineAnnotation);
         mpGraphicsView->deleteConnectionFromClass(pConnectionLineAnnotation);
       }
@@ -1598,20 +1618,20 @@ void BusConnectionDialog::deleteAtomicConnection(QString startConnectorName, QSt
 void BusConnectionDialog::addAtomicConnection(QString startConnectorName, QString endConnectorName)
 {
   // get start connector
-  LibraryTreeItem *pStartLibraryTreeItem = mpConnectionLineAnnotation->getStartComponent()->getLibraryTreeItem();
+  LibraryTreeItem *pStartLibraryTreeItem = mpConnectionLineAnnotation->getStartElement()->getLibraryTreeItem();
   Element *pStartComponent = 0;
-  Element *pBusStartComponent = mpConnectionLineAnnotation->getStartComponent();
-  if (pBusStartComponent && pBusStartComponent->getRootParentComponent()) {
-    pStartComponent = mpGraphicsView->getModelWidget()->getConnectorComponent(pBusStartComponent->getRootParentComponent(), startConnectorName);
+  Element *pBusStartComponent = mpConnectionLineAnnotation->getStartElement();
+  if (pBusStartComponent && pBusStartComponent->getRootParentElement()) {
+    pStartComponent = mpGraphicsView->getModelWidget()->getConnectorElement(pBusStartComponent->getRootParentElement(), startConnectorName);
   } else if (pBusStartComponent) {
     pStartComponent = mpGraphicsView->getElementObject(startConnectorName);
   }
   // get end connector
-  LibraryTreeItem *pEndLibraryTreeItem = mpConnectionLineAnnotation->getEndComponent()->getLibraryTreeItem();
+  LibraryTreeItem *pEndLibraryTreeItem = mpConnectionLineAnnotation->getEndElement()->getLibraryTreeItem();
   Element *pEndComponent = 0;
-  Element *pBusEndComponent = mpConnectionLineAnnotation->getEndComponent();
-  if (pBusEndComponent && pBusEndComponent->getRootParentComponent()) {
-    pEndComponent = mpGraphicsView->getModelWidget()->getConnectorComponent(pBusEndComponent->getRootParentComponent(), endConnectorName);
+  Element *pBusEndComponent = mpConnectionLineAnnotation->getEndElement();
+  if (pBusEndComponent && pBusEndComponent->getRootParentElement()) {
+    pEndComponent = mpGraphicsView->getModelWidget()->getConnectorElement(pBusEndComponent->getRootParentElement(), endConnectorName);
   } else if (pBusEndComponent) {
     pEndComponent = mpGraphicsView->getElementObject(endConnectorName);
   }
@@ -1622,24 +1642,24 @@ void BusConnectionDialog::addAtomicConnection(QString startConnectorName, QStrin
     pNewConnectionLineAnnotation->setOMSConnectionType(oms_connection_single);
 
     QString startComponentName = QStringLiteral("");
-    if (pStartComponent->getParentComponent()) {
-      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentComponent()->getName()).arg(pStartComponent->getName());
+    if (pStartComponent->getParentElement()) {
+      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentElement()->getName()).arg(pStartComponent->getName());
     } else {
       startComponentName = pStartComponent->getName();
     }
-    pNewConnectionLineAnnotation->setStartComponent(pStartComponent);
-    pNewConnectionLineAnnotation->setStartComponentName(startComponentName);
+    pNewConnectionLineAnnotation->setStartElement(pStartComponent);
+    pNewConnectionLineAnnotation->setStartElementName(startComponentName);
 
     QString endComponentName = QStringLiteral("");
-    if (pEndComponent->getParentComponent()) {
-      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentComponent()->getName()).arg(pEndComponent->getName());
+    if (pEndComponent->getParentElement()) {
+      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentElement()->getName()).arg(pEndComponent->getName());
     } else {
       endComponentName = pEndComponent->getName();
     }
-    pNewConnectionLineAnnotation->setEndComponent(pEndComponent);
-    pNewConnectionLineAnnotation->setEndComponentName(endComponentName);
+    pNewConnectionLineAnnotation->setEndElement(pEndComponent);
+    pNewConnectionLineAnnotation->setEndElementName(endComponentName);
 
-    mpGraphicsView->addConnectionToView(pNewConnectionLineAnnotation);
+    mpGraphicsView->addConnectionToView(pNewConnectionLineAnnotation, false);
     if (mpGraphicsView->addConnectionToClass(pNewConnectionLineAnnotation) && pStartLibraryTreeItem->getOMSBusConnector() && pEndLibraryTreeItem->getOMSBusConnector()) {
       pNewConnectionLineAnnotation->setVisible(false);
     } else {
@@ -1654,31 +1674,31 @@ void BusConnectionDialog::addAtomicConnection(QString startConnectorName, QStrin
  */
 void BusConnectionDialog::addBusConnection()
 {
-  if (mAddCase && mpConnectionLineAnnotation->getStartComponent()->getLibraryTreeItem()->getOMSBusConnector()
-      && mpConnectionLineAnnotation->getEndComponent()->getLibraryTreeItem()->getOMSBusConnector()) {
+  if (mAddCase && mpConnectionLineAnnotation->getStartElement()->getLibraryTreeItem()->getOMSBusConnector()
+      && mpConnectionLineAnnotation->getEndElement()->getLibraryTreeItem()->getOMSBusConnector()) {
     QString startComponentName, endComponentName;
-    Element *pStartComponent = mpConnectionLineAnnotation->getStartComponent();
-    if (pStartComponent->getParentComponent()) {
-      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentComponent()->getName()).arg(pStartComponent->getName());
+    Element *pStartComponent = mpConnectionLineAnnotation->getStartElement();
+    if (pStartComponent->getParentElement()) {
+      startComponentName = QString("%1.%2").arg(pStartComponent->getRootParentElement()->getName()).arg(pStartComponent->getName());
     } else {
       startComponentName = pStartComponent->getName();
     }
-    mpConnectionLineAnnotation->setStartComponentName(startComponentName);
-    Element *pEndComponent = mpConnectionLineAnnotation->getEndComponent();
-    if (pEndComponent->getParentComponent()) {
-      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentComponent()->getName()).arg(pEndComponent->getName());
+    mpConnectionLineAnnotation->setStartElementName(startComponentName);
+    Element *pEndComponent = mpConnectionLineAnnotation->getEndElement();
+    if (pEndComponent->getParentElement()) {
+      endComponentName = QString("%1.%2").arg(pEndComponent->getRootParentElement()->getName()).arg(pEndComponent->getName());
     } else {
       endComponentName = pEndComponent->getName();
     }
-    mpConnectionLineAnnotation->setEndComponentName(endComponentName);
+    mpConnectionLineAnnotation->setEndElementName(endComponentName);
     mpConnectionLineAnnotation->setOMSConnectionType(oms_connection_bus);
     mpConnectionLineAnnotation->setLineThickness(0.5);
-    mpGraphicsView->addConnectionToView(mpConnectionLineAnnotation);
+    mpGraphicsView->addConnectionToView(mpConnectionLineAnnotation, false);
     if (mpGraphicsView->addConnectionToClass(mpConnectionLineAnnotation)) {
       addOrDeleteAtomicConnections(mpInputOutputConnectionsModel);
       addOrDeleteAtomicConnections(mpOutputInputConnectionsModel);
-      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Bus Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartComponentName(),
-                                                                                                                   mpConnectionLineAnnotation->getEndComponentName()));
+      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Bus Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartElementName(),
+                                                                                                                   mpConnectionLineAnnotation->getEndElementName()));
       mpGraphicsView->getModelWidget()->updateModelText();
     } else {
       mpGraphicsView->removeCurrentConnection();
@@ -1689,13 +1709,13 @@ void BusConnectionDialog::addBusConnection()
      */
     addOrDeleteAtomicConnections(mpInputOutputConnectionsModel);
     addOrDeleteAtomicConnections(mpOutputInputConnectionsModel);
-    mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Connector %1 to Bus Connection").arg(mpConnectionLineAnnotation->getStartComponentName()));
+    mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Connector %1 to Bus Connection").arg(mpConnectionLineAnnotation->getStartElementName()));
     mpGraphicsView->getModelWidget()->updateModelText();
   } else {
     addOrDeleteAtomicConnections(mpInputOutputConnectionsModel);
     addOrDeleteAtomicConnections(mpOutputInputConnectionsModel);
-    mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Edit Bus Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartComponentName(),
-                                                                                                                      mpConnectionLineAnnotation->getEndComponentName()));
+    mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Edit Bus Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartElementName(),
+                                                                                                                      mpConnectionLineAnnotation->getEndElementName()));
     mpGraphicsView->getModelWidget()->updateModelText();
   }
   accept();
@@ -1772,43 +1792,43 @@ TLMConnectionDialog::TLMConnectionDialog(GraphicsView *pGraphicsView, LineAnnota
 void TLMConnectionDialog::addTLMConnection()
 {
   if (mpDelayTextBox->text().isEmpty()) {
-    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Delay")), Helper::ok);
+    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Delay")), QMessageBox::Ok);
     return;
   }
 
   if (mpAlphaTextBox->text().isEmpty()) {
-    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Alpha")), Helper::ok);
+    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Alpha")), QMessageBox::Ok);
     return;
   }
 
   if (mpLinearImpedanceTextBox->text().isEmpty()) {
-    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Linear Impedance")), Helper::ok);
+    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Linear Impedance")), QMessageBox::Ok);
     return;
   }
 
   if (mpAngularImpedanceTextBox->text().isEmpty()) {
-    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Angular Impedance")), Helper::ok);
+    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::ENTER_VALUE).arg(tr("Angular Impedance")), QMessageBox::Ok);
     return;
   }
 
   if (mAddCase) {
-    Element *pStartElement = mpConnectionLineAnnotation->getStartComponent();
+    Element *pStartElement = mpConnectionLineAnnotation->getStartElement();
     QString startComponentName = QStringLiteral("");
-    if (pStartElement->getParentComponent()) {
-      startComponentName = QString("%1.%2").arg(pStartElement->getRootParentComponent()->getName()).arg(pStartElement->getName());
+    if (pStartElement->getParentElement()) {
+      startComponentName = QString("%1.%2").arg(pStartElement->getRootParentElement()->getName()).arg(pStartElement->getName());
     } else {
       startComponentName = pStartElement->getName();
     }
-    mpConnectionLineAnnotation->setStartComponentName(startComponentName);
+    mpConnectionLineAnnotation->setStartElementName(startComponentName);
 
     QString endComponentName = QStringLiteral("");
-    Element *pEndElement = mpConnectionLineAnnotation->getEndComponent();
-    if (pEndElement->getParentComponent()) {
-      endComponentName = QString("%1.%2").arg(pEndElement->getRootParentComponent()->getName()).arg(pEndElement->getName());
+    Element *pEndElement = mpConnectionLineAnnotation->getEndElement();
+    if (pEndElement->getParentElement()) {
+      endComponentName = QString("%1.%2").arg(pEndElement->getRootParentElement()->getName()).arg(pEndElement->getName());
     } else {
       endComponentName = pEndElement->getName();
     }
-    mpConnectionLineAnnotation->setEndComponentName(endComponentName);
+    mpConnectionLineAnnotation->setEndElementName(endComponentName);
 
     mpConnectionLineAnnotation->setDelay(mpDelayTextBox->text());
     mpConnectionLineAnnotation->setAlpha(mpAlphaTextBox->text());
@@ -1818,10 +1838,10 @@ void TLMConnectionDialog::addTLMConnection()
 
     mpConnectionLineAnnotation->drawCornerItems();
     mpConnectionLineAnnotation->setCornerItemsActiveOrPassive();
-    mpGraphicsView->addConnectionToView(mpConnectionLineAnnotation);
+    mpGraphicsView->addConnectionToView(mpConnectionLineAnnotation, false);
     if (mpGraphicsView->addConnectionToClass(mpConnectionLineAnnotation)) {
-      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Add TLM Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartComponentName(),
-                                                                                                                       mpConnectionLineAnnotation->getEndComponentName()));
+      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Add TLM Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartElementName(),
+                                                                                                                       mpConnectionLineAnnotation->getEndElementName()));
       mpGraphicsView->getModelWidget()->updateModelText();
       accept();
     } else {
@@ -1834,10 +1854,10 @@ void TLMConnectionDialog::addTLMConnection()
     tlmConnectionParameters.linearimpedance = mpLinearImpedanceTextBox->text().toDouble();
     tlmConnectionParameters.angularimpedance = mpAngularImpedanceTextBox->text().toDouble();
 
-    if (OMSProxy::instance()->setTLMConnectionParameters(mpConnectionLineAnnotation->getStartComponent()->getLibraryTreeItem()->getNameStructure(),
-                                                         mpConnectionLineAnnotation->getEndComponent()->getLibraryTreeItem()->getNameStructure(), &tlmConnectionParameters)) {
-      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Edit TLM Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartComponentName(),
-                                                                                                                        mpConnectionLineAnnotation->getEndComponentName()));
+    if (OMSProxy::instance()->setTLMConnectionParameters(mpConnectionLineAnnotation->getStartElement()->getLibraryTreeItem()->getNameStructure(),
+                                                         mpConnectionLineAnnotation->getEndElement()->getLibraryTreeItem()->getNameStructure(), &tlmConnectionParameters)) {
+      mpGraphicsView->getModelWidget()->createOMSimulatorUndoCommand(QString("Edit TLM Connection connect(%1, %2)").arg(mpConnectionLineAnnotation->getStartElementName(),
+                                                                                                                        mpConnectionLineAnnotation->getEndElementName()));
       mpGraphicsView->getModelWidget()->updateModelText();
       accept();
     }
