@@ -366,15 +366,18 @@ oms_status_enu_t oms::ComponentFMUCS::exportToSSD(pugi::xml_node& node, Snapshot
   node.append_attribute("name") = this->getCref().c_str();
   node.append_attribute("type") = "application/x-fmu-sharedlibrary";
   node.append_attribute("source") = getPath().c_str();
-  pugi::xml_node node_connectors = node.append_child(oms::ssp::Draft20180219::ssd::connectors);
 
   if (element.getGeometry())
     element.getGeometry()->exportToSSD(node);
 
-  for (const auto& connector : connectors)
-    if (connector)
-      if (oms_status_ok != connector->exportToSSD(node_connectors))
-        return oms_status_error;
+  if (connectors.size() > 1)
+  {
+    pugi::xml_node node_connectors = node.append_child(oms::ssp::Draft20180219::ssd::connectors);
+    for (const auto& connector : connectors)
+      if (connector)
+        if (oms_status_ok != connector->exportToSSD(node_connectors))
+          return oms_status_error;
+  }
 
   // export ParameterBindings at component level
   values.exportParameterBindings(node, snapshot, variantName);
@@ -617,6 +620,14 @@ oms_status_enu_t oms::ComponentFMUCS::instantiate()
           setResourcesHelper1(res.second);
       }
     }
+    /*
+      check for parameter entry at system level and override the start values if exist,
+      as system level parameter has highest priority, this is done after checking for
+      local resources because it is possible some parameters have local entry and other
+      parameters have top level system entry
+    */
+    if (getParentSystem() && getParentSystem()->getValues().hasResources())
+      setResourcesHelper2(getParentSystem()->getValues());
   }
   // set start values from root resources
   else if (getParentSystem() && getParentSystem()->getValues().hasResources())
